import SVGO from 'svgo'
import utils from './utils.js'
import SvgoConfig from './svgo-config.js'

/**
 * 将svg文件转换为svgicon使用的json对象
 * @param {*} source      svg文件内容
 * @param {*} filename    svg文件名称
 * @returns    svg文件转换后的JSON对象
 */
async function formatSVG(source, filename = 'svg-file') {
  const name = filename.split('.')[0]
  const result = await SVGO.optimize(source, SvgoConfig)
  let data = result.data.replace(/<svg[^>]+>/gi, '').replace(/<\/svg>/gi, '')

  // get view box
  const viewBox = utils.getViewBox(result)

  // add pid attr, for css
  data = utils.addPid(data)

  // rename fill and stroke. (It can restroe in vue-svgicon)
  data = utils.renameStyle(data)

  // replace element id, make sure ID is unique. fix #16
  data = utils.changeId(data, name)

  // escape single quotes
  data = data.replace(/'/g, "\\'")

  const icon = {
    name: `${name}`,
    data: {
      width: result.info.width,
      height: result.info.height,
      viewBox,
      data,
    },
  }
  return icon
}

export default formatSVG
