export default {
  // get svg viewBox
  getViewBox(svgoResult) {
    const viewBoxMatch = svgoResult.data.match(/viewBox="([-\d.]+\s[-\d.]+\s[-\d.]+\s[-\d.]+)"/)
    let viewBox = '0 0 200 200'

    if (viewBoxMatch && viewBoxMatch.length > 1) {
      viewBox = viewBoxMatch[1]
    } else if (svgoResult.info.height && svgoResult.info.width) {
      viewBox = `0 0 ${svgoResult.info.width} ${svgoResult.info.height}`
    }

    return viewBox
  },

  // add pid attr, for css
  addPid(content) {
    const shapeReg = /<(path|rect|circle|polygon|line|polyline|ellipse)\s/gi
    let id = 0
    content = content.replace(shapeReg, function(match) {
      return match + `pid="${id++}" `
    })

    return content
  },

  // rename fill and stroke. (It can restroe in vue-svgicon)
  renameStyle(content) {
    const styleShaeReg = /<(path|rect|circle|polygon|line|polyline|g|ellipse).+>/gi
    const styleReg = /fill="|stroke="/gi
    content = content.replace(styleShaeReg, function(shape) {
      return shape.replace(styleReg, function(styleName) {
        return '_' + styleName
      })
    })

    return content
  },

  // replace element id, make sure ID is unique. fix #16
  changeId(content, name, idSep = '_') {
    const idReg = /svgiconid(\w+)/g
    content = content.replace(idReg, function(match, elId) {
      return `svgiconid${idSep}${name}${idSep}${elId}`
    })

    return content
  },
}
